import nltk
from nltk.corpus import stopwords
from nltk.cluster.util import cosine_distance
import numpy as np
import networkx as nx
from nltk.tokenize import sent_tokenize
from transformers import T5ForConditionalGeneration, T5Tokenizer
import torch

summary_model = T5ForConditionalGeneration.from_pretrained('t5-base')
summary_tokenizer = T5Tokenizer.from_pretrained('t5-base')

device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
summary_model = summary_model.to(device)


def read_article(filedata):
    # commented---------/
    print("before article split============", filedata);
    article = filedata.split(". ")
    # commented---------/
    print("After article split============", article);

    # print("arty",article);
    sentences = []
    # empty array
    # print("sen sen sen",sentences);

    for sentence in article:
        print("sentences before loop===== ", sentence)
        sentences.append(sentence.replace("[^a-zA-Z]", " ").split(" "))
    sentences.pop()
    print("sentences after loop===== ", sentences)
    # print(len(sentences))
    return sentences


def sentence_similarity(sent1, sent2, stopwords=None):
    if stopwords is None:
        stopwords = []

    sent1 = [w.lower() for w in sent1]
    sent2 = [w.lower() for w in sent2]
    # print("sen1 :::::",sent1)
    # print("sen2s :::::",sent2)
    all_words = list(set(sent1 + sent2))
    vector1 = [0] * len(all_words)
    # print("vec1",vector1)
    vector2 = [0] * len(all_words)

    # build the vector for the first sentence
    for w in sent1:
        if w in stopwords:
            continue
        vector1[all_words.index(w)] += 1

    # build the vector for the second sentence
    for w in sent2:
        if w in stopwords:
            continue
        vector2[all_words.index(w)] += 1

    return 1 - cosine_distance(vector1, vector2)


def build_similarity_matrix(sentences, stop_words):
    # Create an empty similarity matrix
    # print(len(sentences)); number of sentences 11
    similarity_matrix = np.zeros((len(sentences), len(sentences)))
    # range means 0 1 2 3 4 5 6 7 8 9 10 11
    for idx1 in range(len(sentences)):
        for idx2 in range(len(sentences)):
            if idx1 == idx2:  # ignore if both are same sentences
                continue
            similarity_matrix[idx1][idx2] = sentence_similarity(sentences[idx1], sentences[idx2], stop_words)
    return similarity_matrix


def generate_summary(file_name, top_n=1):
    # nltk.download("stopwords")
    stop_words = stopwords.words('english')
    # print(stop_words);
    summarize_text = []

    # Step 1 - Read text anc split it
    sentences = read_article(file_name)
    # print("function articles",sentences)
    # Step 2 - Generate Similary Martix across sentences
    sentence_similarity_martix = build_similarity_matrix(sentences, stop_words)

    # Step 3 - Rank sentences in similarity martix
    sentence_similarity_graph = nx.from_numpy_array(sentence_similarity_martix)
    # print("dshfsdjhf sjdhdfbhsdf",sentence_similarity_graph,"uhjhjh")

    scores = nx.pagerank(sentence_similarity_graph, max_iter=1000000)
    # print("score :  ",scores);
    # for i,s in enumerate(sentences):
    #     print(i);
    #     print(s);

    # Step 4 - Sort the rank and pick top sentences
    ranked_sentence = sorted(((scores[i], s) for i, s in enumerate(sentences)), reverse=True)
    # print("Indexes of top ranked_sentence order are ", ranked_sentence)

    for i in range(top_n):
        summarize_text.append(" ".join(ranked_sentence[i][1]))

    # Step 5 - Offcourse, output the summarize texr
    # print("Summarize Text: \n", ". ".join(summarize_text))
    # print( ". ".join(summarize_text))
    x = ". ".join(summarize_text)
    print(x)
    return x

def postprocesstext(content):
    final = ""
    for sent in sent_tokenize(content):
        sent = sent.capitalize()
        final = final + " " + sent
    return final

def summarizer(text):
    text = text.strip().replace("\n", " ")
    text = "summarize: " + text
    # print (text)
    max_len = 512
    encoding = summary_tokenizer.encode_plus(text, max_length=max_len, pad_to_max_length=False, truncation=True,
                                     return_tensors="pt").to(device)

    input_ids, attention_mask = encoding["input_ids"], encoding["attention_mask"]

    outs = summary_model.generate(input_ids=input_ids,
                          attention_mask=attention_mask,
                          early_stopping=True,
                          num_beams=3,
                          num_return_sequences=1,
                          no_repeat_ngram_size=2,
                          min_length=75,
                          max_length=300)

    dec = [summary_tokenizer.decode(ids, skip_special_tokens=True) for ids in outs]
    summary = dec[0]
    summary = postprocesstext(summary)
    summary = summary.strip()

    return summary

# s = generate_summary(
#     "good afternoon everyone I hope honest you can hear me then. see this clear now though is that I need should please let me know when the transfer. okay. %HESITATION this lecture I will be conducting the direction that I'm going to discuss this customers customers customers customers customers customers customers customers. about different types of stuff tracklisting under this topic I'll pick up pick up pick up pick up pick up pick up pick up pick up. they are going to discuss about the function and testing and nonfunctional testing. I didn't do this and check I'm going to discuss about the function and desk. signed it is functionally distinct they are going to discuss about this six six six six six six six six six. type of function of their sting name that you need to think more distinct. send your testing regression testing system testing and finally above that you said you said you said you said you said you said you said you said you. acceptance testing I don't better stick. before moving on to this service option I just think it's just laws we've tried to unload unload unload unload unload unload unload unload. the standard like it's meant by soft about this stick. use of data stick towards pipp coverage of those are done to ensure sure sure sure sure sure sure sure. the quality of fallen off that but it. this is directly usually do this off data stick so for the software testing working working working working working working working. I could do it that would just select something input and we're going to give those test test test test test test test test test test test test test test test. and would still the system and see what are the output generated by the system system system system system system system system. then after that they are going to see but that is generated output put put put put put put put. I think expected. indication at the very beginning but I won't do I decided that it doesn't just important both of both of both of both of both of both of both of. which I needed so that we can be we can just I was just just your structure structure structure structure structure structure after. I asked for the functionality so you have the water with the specification understand what are the father the father the father the father the father the father the father for. functions just about then the system and then there's times that you have to either defined it just just just just just just just just. input something doctor still put so that although. requirement I lost my insurance but it just it. my looking at the specification you have to identified like I live. expected I would put I'm just notification. that's able to build a system and for the system the other to feed this. I realised just input which we have identified. no after that the system was generated that I'll put by going to the operations inside the inside the ten thousand five percent five percent five percent five percent. system. bird I understand that this output according to the expected. so if now acceptable then be able to set that the test cases I guess is I guess is I guess is I guess is I guess is I guess is I guess. what part. a hundred. hello yeah I'm going to set that other justice has been fixed for this system this system system system system system. alright highland see charge off correct asking what do you do wonder software software software software software software. chapter. can be categorised into but I wish one but a common which is functional option option option option option option. interesting and nonfunctional testing. three to this let's just be able to see what I did foundation I can I can I can I can I can I can I. mystic seem to be good through this too explanation it says. a type of testing which ready five that each function. it's about thirty five minutes each function of the software application. I'll put it in conformance with that because I'm an acidic issue going to fine fine fine fine fine fine. how should I was testing from the name is served from the title of services there the only be able to download download download download. the best weather function I did but they don't know what software application. I see that that they are behaving according to the requirement absolutely so if so if so if so if so if. yep beginning the car into the requirement best thing that they'll product is that quality better. that is a one males ensuring the quality of policy about that. okay so here this day in the second point of saying each function function function function function function. sure doctor system is just a by providing appropriate input which we have identified a divided divided divided divided by. bye bye for into the. I would put. %HESITATION just so then selecting the property again input the have got a different one I don't like that they got that they got that they got that they got that they. the third results after that and in the testing process they are giving these inputs temple temple temple temple team. to our system and see whether we get the expected results this axis axis axis axis up. even the actual as I've been what is the letter by the system is equipped. do that expected to start. should I just think that would focus on the functionality that that than that requirement climate climate climate climate quite. perfect cation and able to check whether those functions are according to them because the question quickly quickly quickly. one moment in US I've backed against that is functional just. then the other type is non functional testing there are they able to check for the. nine function I stick so this is the climb up. do any of the specification that's because down on function requirements but the most but most but most but the most but the most. there are also matters these comfortable clothes you offer products and I just a function of a quality quality quality quality quality. one month it custom get a non functional requirements as the. examples got none functional aspects up before months usability but it's but it's but it's but it's but. that I did so in a requirements for certification it might not. I DO to give some performance levels instability levels reliability %HESITATION things like my husband should invention invention invention invention is going. requirement but we have the four percent these as the %HESITATION make up and up of course of course of course of course of course. I love you better. one nine function as six or four month option of extra check whether the effort that is actually that is actually that is actually the. done functional aspect that properly means did you have to do that nine function and I and I and I and I. yes. nine functions that I'm it does which I'm not a does by that function that stick that's perfect perfect perfect perfect. the sometime this and I'm functional that only does might be there as long as the funds are funds of funds of funds. xin'an aspect in this afternoon it depends on the better but in most of the guest service the the the the. before months usability and reliability I'm not functional aspects what it doesn't. after you get. six different type of function of their stick is an extra expected that means I've been I've been I've been I've been. we go after the new year they're going to discuss about that nonfunctional definitely. okay so the very first function testing able to discuss it you need to Smith the Smith the Smith the Smith. it's like the smallest does think that's me I've got as a functional problem I suppose I suppose I suppose. sure there stick so in this you need to speak. the other dogs for good on a single you need. the system and I'm going to guess that you need independent that's a he said so he said so he said so he said. yeah says a process office did the individual subprogram subroutine brought brought brought brought. ing Carson or procedures involving a completely stumped. idea collection of this you need under your need testing we are only going to going to going to going to go. before good honest this is big you need and check whether there's you need is a quality product that's that's that's that's. yeah it's a big issue. probably you need to stick it is a seven that this is this is. you need testing is it used to is the task of nearby. okay. okay now it's yep. it is that you need testing reset that is used to is the task of developing but it but it but it but. the reason is from this or you need to speak like that going to do a hundred to a hundred dollars I don't know if. please we are going to a. %HESITATION individual you need at the time both of and I'm going to focus on the other hand. and that the stuff they're wonderful because I'm not individual you need at that time so in the store in the store in the store in the. active any issues that that's the only you need to be sorted out but it should be expected to street unit to. mystic so one side we have company don't you need testing for each and every component component component component. in other system we can ensure that this government W. W. W. dot. once up and actually independently so in that case it makes the need but the but the but the but. okay is it better than completely checking on complaints together as one one one one seven. and trying to identify the issue if they have first check this individual unit. and then once they are all right if you're going to go for the booking system the the the the. it is is it because knowing on if you need works perfectly fine with the. data should and there she was might be because of the defendant's there's another unit that I was better I said I said I said. if we start to need testing if you're going for the quarter system advance. dampen this or many issues I'm getting inside the your needs because I've been dependent depend on depend on depend on depend on. so the bit this is going to a nearby so that is right yeah I think thanks thanks thanks. you need testing is as the task got even. testing is performed by the dealer both up it is not going to go for another discover discover discover does. after. a. also is the company didn't computer that you need your service but what you need to speak the speaker speaker speed. ing and see whether that you need here your she has built is the car into the pacifica to begin to begin to begin.",
#     10)

